@@ -6,25 +6,12 @@ use TestML::Runner -base;
 
 use Test::Builder;
 
-field 'test_builder' => -init => 'Test::Builder->new';
-
-sub init_bridge {
-    my $self = shift;
-
-    local @INC = ('t', 't/lib', @INC);
-    my $class = $self->bridge;
-    if ($class ne 'main') {
-        eval "require $class";
-        die "Error loading bridge class '$class': $@" if $@;
-    }
-
-    return $class->new();
-}
+has 'test_builder' => -init => 'Test::Builder->new';
 
 sub title {
     my $self = shift;
     if (my $title = $self->doc->meta->data->{Title}) {
-        print "=== $title ===\n";
+        $self->test_builder->note("=== $title ===\n");
     }
 }
 
@@ -38,19 +25,12 @@ sub plan_begin {
     }
 }
 
-sub plan_end {
-}
-
-# TODO - Refactor so that standard lib finds this comparison through EQ
-sub do_test {
+sub EQ {
     my $self = shift;
-    my $operator = shift;
     my $left = shift;
     my $right = shift;
     my $label = shift;
-    if ($operator eq 'EQ') {
-        $self->test_builder->is_eq($left->value, $right->value, $label);
-    }
+    $self->test_builder->is_eq($left->value, $right->value, $label);
 }
 
 1;
